Documentation
¶
Overview ¶
Package v1alpha1 contains API Schema definitions for the clusterlendingmanager v1alpha1 API group +kubebuilder:object:generate=true +groupName=clusterlendingmanager.dtaniwaki.github.com
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "clusterlendingmanager.dtaniwaki.github.com", Version: "v1alpha1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type DaySchedule ¶
type DaySchedule struct {
// Hours is ...
Hours []Schedule `json:"hours,omitempty"`
}
DaySchedule is ...
func (*DaySchedule) DeepCopy ¶
func (in *DaySchedule) DeepCopy() *DaySchedule
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DaySchedule.
func (*DaySchedule) DeepCopyInto ¶
func (in *DaySchedule) DeepCopyInto(out *DaySchedule)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LendingConfig ¶
type LendingConfig struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec LendingConfigSpec `json:"spec,omitempty"`
Status LendingConfigStatus `json:"status,omitempty"`
}
LendingConfig is the Schema for the lendingconfigs API
func (*LendingConfig) DeepCopy ¶
func (in *LendingConfig) DeepCopy() *LendingConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LendingConfig.
func (*LendingConfig) DeepCopyInto ¶
func (in *LendingConfig) DeepCopyInto(out *LendingConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*LendingConfig) DeepCopyObject ¶
func (in *LendingConfig) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type LendingConfigList ¶
type LendingConfigList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []LendingConfig `json:"items"`
}
LendingConfigList contains a list of LendingConfig
func (*LendingConfigList) DeepCopy ¶
func (in *LendingConfigList) DeepCopy() *LendingConfigList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LendingConfigList.
func (*LendingConfigList) DeepCopyInto ¶
func (in *LendingConfigList) DeepCopyInto(out *LendingConfigList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*LendingConfigList) DeepCopyObject ¶
func (in *LendingConfigList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type LendingConfigSpec ¶
type LendingConfigSpec struct {
// Timezone is ...
Timezone string `json:"timezone,omitempty"`
// Schedules is ...
Schedule ScheduleSpec `json:"schedule,omitempty"`
// TargetRefs is ...
Targets []Target `json:"targets,omitempty"`
}
LendingConfigSpec defines the desired state of LendingConfig
func (*LendingConfigSpec) DeepCopy ¶
func (in *LendingConfigSpec) DeepCopy() *LendingConfigSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LendingConfigSpec.
func (*LendingConfigSpec) DeepCopyInto ¶
func (in *LendingConfigSpec) DeepCopyInto(out *LendingConfigSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LendingConfigStatus ¶
type LendingConfigStatus struct {
// LendingReferences is ...
LendingReferences []LendingReference `json:"objectReferences,omitempty"`
}
LendingConfigStatus defines the observed state of LendingConfig
func (*LendingConfigStatus) DeepCopy ¶
func (in *LendingConfigStatus) DeepCopy() *LendingConfigStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LendingConfigStatus.
func (*LendingConfigStatus) DeepCopyInto ¶
func (in *LendingConfigStatus) DeepCopyInto(out *LendingConfigStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LendingReference ¶
type LendingReference struct {
// ObjectReference is ...
ObjectReference `json:"objectReference,omitempty"`
// Replicas is ...
Replicas int64 `json:"replicas,omitempty"`
}
LendingReference is ...
func (*LendingReference) DeepCopy ¶
func (in *LendingReference) DeepCopy() *LendingReference
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LendingReference.
func (*LendingReference) DeepCopyInto ¶
func (in *LendingReference) DeepCopyInto(out *LendingReference)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ObjectReference ¶
type ObjectReference struct {
// APIVersion is ...
APIVersion string `json:"apiVersion,omitempty"`
// Kind is ...
Kind string `json:"kind,omitempty"`
// Name is ...
Name string `json:"name,omitempty"`
}
ObjectReference contains enough information to let you locate the typed referenced object inside the same namespace.
func (*ObjectReference) DeepCopy ¶
func (in *ObjectReference) DeepCopy() *ObjectReference
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ObjectReference.
func (*ObjectReference) DeepCopyInto ¶
func (in *ObjectReference) DeepCopyInto(out *ObjectReference)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Schedule ¶
type Schedule struct {
// Start is ...
Start *string `json:"start,omitempty"`
// End is ...
End *string `json:"end,omitempty"`
}
Schedule is ...
func (*Schedule) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Schedule.
func (*Schedule) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ScheduleSpec ¶
type ScheduleSpec struct {
// Default is ...
Default *DaySchedule `json:"default,omitempty"`
// Monday is ...
Monday *DaySchedule `json:"monday,omitempty"`
// Tuesday is ...
Tuesday *DaySchedule `json:"tuesday,omitempty"`
// Wednesday is ...
Wednesday *DaySchedule `json:"wednesday,omitempty"`
// Thursday is ...
Thursday *DaySchedule `json:"thursday,omitempty"`
// Friday is ...
Friday *DaySchedule `json:"friday,omitempty"`
// Saturday is ...
Saturday *DaySchedule `json:"saturday,omitempty"`
// Sunday is ...
Sunday *DaySchedule `json:"sunday,omitempty"`
// Always is ...
Always bool `json:"always,omitempty"`
}
Schedule is ...
func (*ScheduleSpec) DeepCopy ¶
func (in *ScheduleSpec) DeepCopy() *ScheduleSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ScheduleSpec.
func (*ScheduleSpec) DeepCopyInto ¶
func (in *ScheduleSpec) DeepCopyInto(out *ScheduleSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Target ¶
type Target struct {
// APIVersion is ...
APIVersion string `json:"apiVersion,omitempty"`
// Kind is ...
Kind string `json:"kind,omitempty"`
// Name is ...
Name *string `json:"name,omitempty"`
// DefaultReplicas
DefaultReplicas *int64 `json:"defaultReplicas,omitempty"`
}
Target is ...
func (*Target) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Target.
func (*Target) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.